pub struct BleChannels;Expand description
A namespace of methods to manage the supported range of BLE channels.
Implementations
Sourceimpl BleChannels
impl BleChannels
Sourcepub fn index_of(channel: u8) -> Option<usize>
pub fn index_of(channel: u8) -> Option<usize>
Get the index of BLE_CHANNEL for the given channel.
Returns None if the given current channel is not in BLE_CHANNEL.